# Community contributions
We love community contributions! :heart:

This page is to celebrate and showcase the contributors that have gone above and beyond!

!!! note annotate "Is your work not listed here?"
    We do our best to list all the work we are aware of, but if we missed your contribution feel free to [open a Github issue](https://github.com/datamol-io/molfeat/issues/new?assignees=&labels=needs+triage%2Cdocs%2Cenhancement&projects=&template=5_community_contribution.yaml) to let us know! We will add it as soon as possible.

## Plugins
Plugins add new featurizers to the molfeat ecosystem by extending its functionality with plug-and-play components. To learn more, see [Extending molfeat](../developers/create-plugin.md).

| **Link**                                                                                                                                             | **Name**      | **Author**                                   | **Description**                                                                                                                                             |
|------------------------------------------------------------------------------------------------------------------------------------------------------|---------------|----------------------------------------------|-------------------------------------------------------------------------------------------------------------------------------------------------------------|
| [![github](https://img.shields.io/badge/GitHub-100000?style=for-the-badge&logo=github&logoColor=white)](https://github.com/datamol-io/molfeat-padel) | molfeat-padel | [@datamol.io](https://github.com/datamol-io) | Adds support for the PaDeL descriptors, as introduced by [Yap, 2010](https://doi.org/10.1002/jcc.21707). This is the official exemplary plugin for molfeat. |
| [![github](https://img.shields.io/badge/GitHub-100000?style=for-the-badge&logo=github&logoColor=white)](https://github.com/maclandrol/molfeat-hype)  | molfeat-hype  | [@maclandrol](https://github.com/maclandrol) | Investigates the performance of embeddings from various LLMs trained without explicit molecular context for molecular modeling                              |

## Tutorials
Tutorials allow newcomers to quickly get their hands dirty with step-by-step instructions. It's therefore great that some of our community members have taken the time to demonstrate how they use molfeat.

| **Link**                                                                                                                                                                                                                                                 | **Name**                               | **Author**                                                            | **Description**                                                                                                                                                                             | 
|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|----------------------------------------|-----------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/PatWalters/practical_cheminformatics_tutorials/blob/main/ml_models/QSAR_in_8_lines.ipynb)                                          | <nobr>Practical cheminformatics</nobr> | [@PatWalters](https://github.com/PatWalters)                          | This tutorial shows how to train a QSAR using just 8 lines of code, among others by utilizing tools from the [datamol.io](https://datamol.io/) ecosystem.                                   |
| [![Run on Gradient](https://camo.githubusercontent.com/c9931a1689c37ab786edd3e1e5f59b9a6f7d097628c4689ce2432563ef884524/68747470733a2f2f6173736574732e706170657273706163652e696f2f696d672f6772616469656e742d62616467652e737667)](https://ipu.dev/lDvDHL) | PyG GNN on Graphcore IPUs              | <nobr>[@s-maddrellmander](https://github.com/s-maddrellmander)</nobr> | This tutorial adapts the [Training a GNN with PyG](../tutorials/pyg_integration.ipynb) to show how to leverage [Graphcore IPUs](https://www.graphcore.ai/products/ipu).                     |
| [![Run on Gradient](https://camo.githubusercontent.com/c9931a1689c37ab786edd3e1e5f59b9a6f7d097628c4689ce2432563ef884524/68747470733a2f2f6173736574732e706170657273706163652e696f2f696d672f6772616469656e742d62616467652e737667)](https://ipu.dev/yoyy6N) | Transformer on Graphcore IPUs          | <nobr>[@s-maddrellmander](https://github.com/s-maddrellmander)</nobr> | This tutorial adapts the [Finetuning a pre-trained transformer](../tutorials/transformer_finetuning.ipynb) to show how to leverage [Graphcore IPUs](https://www.graphcore.ai/products/ipu). |


## Code
From bug fixes to new features, code contributions directly benefit the molfeat package and everyone that uses it! 

<a href="https://github.com/datamol-io/molfeat/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=datamol-io/molfeat" />
</a>